==> haskell-tamarin-prover-accountability-1.10.0-140.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-accountability
version:              1.10.0
visibility:           public
id:                   tamarin-prover-accountability-1.10.0-AcvwRRZw84OI64udR6LAkh
key:                  tamarin-prover-accountability-1.10.0-AcvwRRZw84OI64udR6LAkh
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  1c734447db4fe32b847b95f8dab97f09
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.10.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.10.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.10.0-AcvwRRZw84OI64udR6LAkh

depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-pretty-0.8.10-CQgtmRgYKKmDAUdx88Og8E base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    fclabels-2.0.5.1-B0gUDKSsP9U7jQgl6QEiPn mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD parsec-3.1.16.1
    process-1.6.19.0 raw-strings-qq-1.1-9aHRjJohGsnIZrEMWY5Obp
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    tamarin-prover-term-1.10.0-7lg7fyb9gsV8X7rKS2j9F8
    tamarin-prover-theory-1.10.0-7y5uJxUgrdx5jvewnXl64g
    tamarin-prover-utils-1.10.0-AuSLTuIvPss6OvOOm3zOpL text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-accountability-1.10.0-141-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-accountability
version:              1.10.0
visibility:           public
id:                   tamarin-prover-accountability-1.10.0-2HF1JL3BKqsFYdNGioZEHc
key:                  tamarin-prover-accountability-1.10.0-2HF1JL3BKqsFYdNGioZEHc
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  0ffdb7905d655cf507183a42a23bef75
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.10.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.10.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.10.0-2HF1JL3BKqsFYdNGioZEHc

depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    fclabels-2.0.5.1-Cm4CiwTnZxL5PpaOaNOe5j mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD parsec-3.1.16.1
    process-1.6.19.0 raw-strings-qq-1.1-HgsCJbBD5QVLggpDhmUWHl
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    tamarin-prover-term-1.10.0-8m1cmiZoh6pIs2QTsHMG1e
    tamarin-prover-theory-1.10.0-FQdbJN1HTJM4v4YRI8QIob
    tamarin-prover-utils-1.10.0-Ic9mtk7pOR48tkJCsqQc0x text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-KGH5CSn0bIt6TRjVfDPPFU

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
